## 任务类型(Task Type)
无线能效优化

## 任务描述(Task Description)
基于<任务对象>、<任务上下文>、<约束条件>输出能效优化方案，达成<任务目标>中定义的能效优化目标，按照<预期输出>中定义的结构返回能效优化的结果。

## 任务目标(Task Target)
{{任务目标}}（可选）
要求：定义任务需达成的量化或定性目标，如能效目标和速率保障目标。均为可选参数。
任务级节能的具体目标说明：
1. 能耗目标：节能的增益目标，目标值格式必须为百分比，如总功耗降低的百分比。举例：能耗目标：30%
2. 速率保障目标：需要保障的下行吞吐率目标最小值。举例：速率保障目标：50Mbps/s

## 任务对象(Task Object)
{{任务对象}}（必选）
要求：明确指定节能区域信息，地理或逻辑区域（如：区级行政单位）或经纬度坐标。区域信息为必选参数。
以下是具体说明：
1. 地理/逻辑的区域名称，举例：区域：“松山湖管委会”，坐标（112.0,20.6）区域
2. **重要**：区域信息，是具体物理地址，例如：“松山湖管委会”这种物理真实小区，而不是“所有小区”、“室内小区”、“室外小区”这种无具体物理位置的描述信息

## 任务上下文(Task Context)
{{任务上下文}}（可选）
要求：提供任务执行的背景和上下文信息。可选参数。

## 约束条件(Constraints)
{{约束条件}}（可选）
要求：列出任务执行中必须遵守的规则、限制和边界条件，约束条件默认对区域内所有场景均适用，针对区域内指定场景适用的约束条件，请单独说明。均为可选参数。
1. 需要节能的小区类型（室内/室外/所有），举例：节能的小区类型：室外
2. 节能的小区制式（LTE/NR/全部），举例：节能的小区制式：NR
3. 对基础层和容量层的频点要求，频点的表述方式必须为下行频点号，举例：1650频点做载波关断的基础层
4. 节能的激进程度是激进节能还是保守节能，举例：节能激进程度：激进节能
5. 是否要求体验无损节能，举例：是否要求体验无损节能：是
6. 需要执行节能的时间段区间范围，以天为周期循环执行，例如：需要节能的时间范围：起始时间“08:00:00”，结束时间“12:00:00”
7. 针对区域内制定场景适用的约束条件（如：铁路/黑森林/商务区/居民区），举例：商业区场景禁止1300频点做容量层；黑森林场景禁止在0-6点开通休眠
8. 是否允许在节能时关闭载波的频点，举例：载波关断频点特殊要求：不可关断

## 预期输出(Expected Output)
要求：输出能效优化任务的意图报告，意图报告应包含以下信息：
### 意图报告基本信息
1. 能效优化报告的唯一标识
2. 节能任务唯一标识
3. 总体意图的执行结果，执行结果包括执行结果状态，执行结果详情，如果未达成目标，描述未达成的具体原因。
### 意图报告详细信息
1. 具体KPI的执行结果，执行结果包括执行结果状态，执行结果详情，如果未达成目标，描述未达成的具体原因。
